==> openGion6.6.0.1_core.zip: uap/webapps/ge/db/SQLSERVER/sql/install/01_TABLE/GEA11S.sql <==
/****************************************************************************/
/* GEA11 ( 画面定義 )                                                       */
/*                                                                          */
/* Created : 2016/10/27 10:57:15                                            */
/****************************************************************************/

CREATE TABLE GEA11 (
   SYSTEM_ID        varchar           (   10 )                  NOT NULL            /*  10 ｼｽﾃﾑID   */
 , SEQNO            INTEGER                         DEFAULT 0   NOT NULL            /*  20 表示順   */
 , GUIKEY           varchar           (   30 )                  NOT NULL            /*  30 画面ID   */
 , GUILVL           varchar           (    1 )      DEFAULT 3   NOT NULL            /*  40 画面Lv   */
 , LABEL_CLM        varchar           (   30 )                                      /*  45 ﾗﾍﾞﾙｶﾗﾑ  */
 , GROUPS           varchar           (  500 )                                      /*  50 ｸﾞﾙｰﾌﾟｽ  */
 , NAME_JA          varchar           (  200 )                                      /*  60 名称     */
 , ADDRESS          varchar           (  256 )                                      /*  70 ｱﾄﾞﾚｽ    */
 , ROLES            varchar           ( 1000 )                                      /*  80 ﾛｰﾙｽﾞ    */
 , RWMODE           varchar           (    3 )                                      /*  90 ﾓｰﾄﾞ     */
 , TARGET           varchar           (   10 )                                      /* 100 ﾀｰｹﾞｯﾄ   */
 , PARAM            varchar           (  500 )                                      /* 110 設定値   */
 , KBLINK           varchar           (   10 )                                      /* 120 ﾘﾝｸ区分  */
 , COMMENTS         varchar           (  500 )                                      /* 130 ｺﾒﾝﾄ     */
 , CDKH             varchar           (    1 )                                      /* 140 改廃ｺｰﾄﾞ */
 , KBSAKU           varchar           (    1 )      DEFAULT 1   NOT NULL            /* 150 作成区分 */
 , RELEASE_NOTES    varchar           (  120 )                                      /* 160 ﾘﾘｰｽﾉｰﾄ  */
 , RDC_CODE         varchar           (   20 )                                      /* 170 設変番号 */
 , UNIQ             int IDENTITY(1,1)                                               /* 800 ﾕﾆｰｸｷｰ   */
 , FGJ              varchar           (    1 )      DEFAULT 1   NOT NULL            /* 810 状態ﾌﾗｸﾞ */
 , DYSET            varchar           (   14 )                                      /* 820 登録日時 */
 , PGSET            varchar           (   10 )                                      /* 830 作成PG   */
 , PGPSET           varchar           (   10 )                                      /* 840 作成親PG */
 , USRSET           varchar           (   10 )                                      /* 850 作成社員 */
 , DYUPD            varchar           (   14 )                                      /* 860 更新日時 */
 , PGUPD            varchar           (   10 )                                      /* 870 更新PG   */
 , PGPUPD           varchar           (   10 )                                      /* 880 更新親PG */
 , USRUPD           varchar           (   10 )                                      /* 890 更新者   */
);

==> openGion6.8.5.0_core.zip: uap/webapps/ge/db/SQLSERVER/sql/install/01_TABLE/GEA11S.sql <==
/****************************************************************************/
/* GEA11 ( 画面定義 )                                                       */
/*                                                                          */
/* Created : 2017/07/18 08:42:12                                            */
/****************************************************************************/

CREATE TABLE GEA11 (
   SYSTEM_ID        varchar           (   10 )                  NOT NULL            /*  10 ｼｽﾃﾑID   */
 , SEQNO            INTEGER                         DEFAULT 0   NOT NULL            /*  20 表示順   */
 , GUIKEY           varchar           (   30 )                  NOT NULL            /*  30 画面ID   */
 , GUILVL           varchar           (    1 )      DEFAULT '3' NOT NULL            /*  40 画面Lv   */
 , LABEL_CLM        varchar           (   30 )                                      /*  45 ﾗﾍﾞﾙｶﾗﾑ  */
 , GROUPS           varchar           (  500 )                                      /*  50 ｸﾞﾙｰﾌﾟｽ  */
 , NAME_JA          varchar           (  200 )                                      /*  60 名称     */
 , ADDRESS          varchar           (  256 )                                      /*  70 ｱﾄﾞﾚｽ    */
 , ROLES            varchar           ( 2000 )                                      /*  80 ﾛｰﾙｽﾞ    */
 , RWMODE           varchar           (    3 )                                      /*  90 ﾓｰﾄﾞ     */
 , TARGET           varchar           (   10 )                                      /* 100 ﾀｰｹﾞｯﾄ   */
 , PARAM            varchar           (  500 )                                      /* 110 設定値   */
 , KBLINK           varchar           (   10 )                                      /* 120 ﾘﾝｸ区分  */
 , COMMENTS         varchar           (  500 )                                      /* 130 ｺﾒﾝﾄ     */
 , CDKH             varchar           (    1 )                                      /* 140 改廃ｺｰﾄﾞ */
 , KBSAKU           varchar           (    1 )      DEFAULT '1' NOT NULL            /* 150 作成区分 */
 , RELEASE_NOTES    varchar           (  120 )                                      /* 160 ﾘﾘｰｽﾉｰﾄ  */
 , RDC_CODE         varchar           (   20 )                                      /* 170 設変番号 */
 , UNIQ             int IDENTITY(1,1)                                               /* 800 ﾕﾆｰｸｷｰ   */
 , FGJ              varchar           (    1 )      DEFAULT '1' NOT NULL            /* 810 状態ﾌﾗｸﾞ */
 , DYSET            varchar           (   14 )                                      /* 820 登録日時 */
 , PGSET            varchar           (   10 )                                      /* 830 作成PG   */
 , PGPSET           varchar           (   10 )                                      /* 840 作成親PG */
 , USRSET           varchar           (   10 )                                      /* 850 作成社員 */
 , DYUPD            varchar           (   14 )                                      /* 860 更新日時 */
 , PGUPD            varchar           (   10 )                                      /* 870 更新PG   */
 , PGPUPD           varchar           (   10 )                                      /* 880 更新親PG */
 , USRUPD           varchar           (   10 )                                      /* 890 更新者   */
);
